@@ -449,6 +449,9 @@ class Repres:
         )
         return "?"
 
+    def used_when_computing_free_data_grid(self):
+        raise NotImplementedError()
+
 
 class Field(Repres):
     accuracy = PgenAccuracy()
@@ -515,6 +518,9 @@ class Field(Repres):
 
         return " ".join(str(e) for e in explain)
 
+    def used_when_computing_free_data_grid(self):
+        return True
+
 
 class Area:
     def __init__(self, north, west, south, east, tag="XXX:XX"):
@@ -1198,6 +1204,9 @@ class TF(Repres):
     def details(self):
         return f"area: {self.area}"
 
+    def used_when_computing_free_data_grid(self):
+        return False
+
 
 REPRES = {
     ("reduced_gg", "sh"): Mixed,
